pub enum InstallError {
Cancelled,
FailedToReadPathsJson(Error),
FailedToReadIndexJson(Error),
FailedToReadLinkJson(Error),
FailedToLink(PathBuf, LinkFileError),
FailedToCreateDirectory(PathBuf, Error),
TargetPrefixIsNotUtf8,
FailedToCreateTargetDirectory(Error),
MissingPythonInfo,
FailedToCreatePythonEntryPoint(Error),
PostProcessFailed(Error),
}Expand description
An error that might occur when installing a package.
Variants
Cancelled
The operation was cancelled.
FailedToReadPathsJson(Error)
The paths.json file could not be read.
FailedToReadIndexJson(Error)
The index.json file could not be read.
FailedToReadLinkJson(Error)
The link.json file could not be read.
FailedToLink(PathBuf, LinkFileError)
A file could not be linked.
FailedToCreateDirectory(PathBuf, Error)
A directory could not be created.
TargetPrefixIsNotUtf8
The target prefix is not UTF-8.
FailedToCreateTargetDirectory(Error)
Failed to create the target directory.
MissingPythonInfo
A noarch package could not be installed because no python version was specified.
FailedToCreatePythonEntryPoint(Error)
Failed to create a python entry point for a noarch package.
PostProcessFailed(Error)
When post-processing of the environment fails. Post-processing involves removing clobbered paths.