Enum InstallationResultRecord

pub enum InstallationResultRecord {
    Max(PrefixRecord),
    Min(MinimalPrefixRecord),
}
Special kind of record that either can be either minimal or full.

In case where nothing changed transaction will be noop and to check this we have to read only few fields of PrefixRecord which are entailed in MinimalPrefixRecord.

Without this structure we would have to inject MinimalPrefixRecord to PrefixRecord which could lead to unexpected results.

Variants



Max(PrefixRecord)

Full record.



Min(MinimalPrefixRecord)

Minimal record.

Implementations

Source

impl InstallationResultRecord

pub fn into_prefix_record( self, prefix: impl AsRef<Path>, ) -> Result<PrefixRecord, Error>

Either just returns stored PrefixRecord or parses PrefixRecord from the given prefix.

pub fn name(&self) -> &PackageName

Return reference to the underlying PackageName.

pub fn version(&self) -> &VersionWithSource

Return reference to the underlying VersionWithSource.

pub fn build(&self) -> &str

Return reference to the underlying build string.

pub fn sha256(&self) -> Option<&Sha256Hash>

Return reference to the underlying Sha256Hash.

pub fn md5(&self) -> Option<&Md5Hash>

Return reference to the underlying Md5Hash.

pub fn size(&self) -> Option<u64>

Return reference to the underlying content size.

pub fn noarch(&self) -> NoArchType

Return reference to the underlying NoArchType.

pub fn python_site_packages_path(&self) -> Option<&str>

Return reference to the underlying python_site_packages_path.

pub fn requested_spec(&self) -> Option<&String>

Return reference to the underlying requested_spec.

pub fn requested_specs(&self) -> &Vec<String>

Return reference to the underlying requested_specs.