pub enum Placement {
Before(ProgressBar),
After(ProgressBar),
Index(usize),
End,
}Expand description
Defines how to place the progress bars. Note that the three progress bars of the reporter are always kept together in the same order. This placement refers to how the group of progress bars is placed.
Variants
Before(ProgressBar)
Place all progress bars before the given progress bar.
After(ProgressBar)
Place all progress bars after the given progress bar
Index(usize)
Place all progress bars at the given index
End
Place all progress bars as the last progress bars.