Enum TransactionOperation

pub enum TransactionOperation<Old, New> {
    Install(New),
    Change {
        old: Old,
        new: New,
    },
    Reinstall {
        old: Old,
        new: New,
    },
    Remove(Old),
}
Describes an operation to perform

Variants



Install(New)

The given package record should be installed



Change

Remove an old package and install another

Fields

old: Old

The old record to remove

new: New

The new record to install



Reinstall

Reinstall a package. This can happen if the Python version changed in the environment, we need to relink all noarch python packages in that case. Includes old and new because certain fields like the channel/url may have changed between installations

Fields

old: Old

The old record to remove

new: New

The new record to install



Remove(Old)

Completely remove a package

Implementations

Source

impl<Old: Clone, New: Clone> TransactionOperation<&Old, &New>

pub fn to_owned(self) -> TransactionOperation<Old, New>

Own records.

Source

impl<Old, New> TransactionOperation<Old, New>

pub fn record_to_install(&self) -> Option<&New>

Returns the record of the package to install for this operation. If this operation does not refer to an installable package, None is returned.

Source

impl<Old, New> TransactionOperation<Old, New>

pub fn record_to_remove(&self) -> Option<&Old>

Returns the record of the package to remove for this operation. If this operation does not refer to an removable package, None is returned.