Function link_package

pub async fn link_package(
    package_dir: &Path,
    target_dir: &Prefix,
    driver: &InstallDriver,
    options: InstallOptions,
) -> Result<Vec<PathsEntry>, InstallError>
Given an extracted package archive (package_dir), installs its files to the target_dir.

Returns a [PathsEntry] for every file that was linked into the target directory. The entries are ordered in the same order as they appear in the paths.json file of the package.