pub struct IndicatifReporterBuilder<F: ProgressFormatter> { /* private fields */ }Expand description
A builder to construct an IndicatifReporter.
Implementations
Sourceimpl<F: ProgressFormatter> IndicatifReporterBuilder<F>
impl<F: ProgressFormatter> IndicatifReporterBuilder<F>
Sourcepub fn with_formatter<T: ProgressFormatter>(
self,
formatter: T,
) -> IndicatifReporterBuilder<T>
pub fn with_formatter<T: ProgressFormatter>( self, formatter: T, ) -> IndicatifReporterBuilder<T>
Sets the formatter to use for the progress bars.
Sourcepub fn with_multi_progress(self, multi_progress: MultiProgress) -> Self
pub fn with_multi_progress(self, multi_progress: MultiProgress) -> Self
Sets the [indicatif::MultiProgress] to use for the progress bars.
Sourcepub fn clear_when_done(self, clear_when_done: bool) -> Self
pub fn clear_when_done(self, clear_when_done: bool) -> Self
Sets whether the progress bars are cleared when the transaction is complete.
Sourcepub fn with_placement(self, placement: Placement) -> Self
pub fn with_placement(self, placement: Placement) -> Self
Defines how the progress bars of the reporter are placed relative to any other progress bars that are already present.
Sourcepub fn finish(self) -> IndicatifReporter<F>
pub fn finish(self) -> IndicatifReporter<F>
Finish building IndicatifReporter.