pub struct LinkOptions {
pub allow_symbolic_links: Option<bool>,
pub allow_hard_links: Option<bool>,
pub allow_ref_links: Option<bool>,
}Expand description
Defines which operations can be used to link files to disk.
Fields
allow_symbolic_links: Option<bool>If true, symbolic links will be allowed to install files to the disk.
Defaults to true if None.
allow_hard_links: Option<bool>If true, hard links will be allowed to install files to the disk.
Defaults to true if None.
allow_ref_links: Option<bool>If true, ref links (or copy-on-write links) will be allowed to install
files to the disk. Defaults to true if None.