Trait ProgressFormatter

pub trait ProgressFormatter {
    // Required method
    fn format(&self, props: &ProgressStyleProperties) -> ProgressStyle;
}
A trait that can be used to customize the style of different progress bars of a IndicatifReporter.

Required Methods

fn format(&self, props: &ProgressStyleProperties) -> ProgressStyle

Returns a progress bar style for the given properties.

Implementors