pub enum InstallationResultRecord {
Max(PrefixRecord),
Min(MinimalPrefixRecord),
}Expand description
Special kind of record that either can be either minimal or full.
In case where nothing changed transaction will be noop and to
check this we have to read only few fields of PrefixRecord which
are entailed in MinimalPrefixRecord.
Without this structure we would have to inject
MinimalPrefixRecord to PrefixRecord which could lead to
unexpected results.
Variants
Implementations
Sourceimpl InstallationResultRecord
impl InstallationResultRecord
Sourcepub fn into_prefix_record(
self,
prefix: impl AsRef<Path>,
) -> Result<PrefixRecord, Error>
pub fn into_prefix_record( self, prefix: impl AsRef<Path>, ) -> Result<PrefixRecord, Error>
Either just returns stored PrefixRecord or parses PrefixRecord from the given prefix.
Sourcepub fn version(&self) -> &VersionWithSource
pub fn version(&self) -> &VersionWithSource
Return reference to the underlying VersionWithSource.
Sourcepub fn python_site_packages_path(&self) -> Option<&str>
pub fn python_site_packages_path(&self) -> Option<&str>
Return reference to the underlying python_site_packages_path.
Sourcepub fn requested_spec(&self) -> Option<&String>
pub fn requested_spec(&self) -> Option<&String>
Return reference to the underlying requested_spec.
Sourcepub fn requested_specs(&self) -> &Vec<String>
pub fn requested_specs(&self) -> &Vec<String>
Return reference to the underlying requested_specs.