pub trait ProgressFormatter {
// Required method
fn format(&self, props: &ProgressStyleProperties) -> ProgressStyle;
}Expand description
A trait that can be used to customize the style of different progress bars
of a IndicatifReporter.
pub trait ProgressFormatter {
// Required method
fn format(&self, props: &ProgressStyleProperties) -> ProgressStyle;
}A trait that can be used to customize the style of different progress bars
of a IndicatifReporter.